@@ -751,13 +751,31 @@ impl<C> GasOps for DefaultKernel<C>
 where
     C: CallManager,
 {
+    fn gas_used(&self) -> i64 {
+        self.call_manager.gas_tracker().gas_used()
+    }
+
+    fn milligas_used(&self) -> i64 {
+        self.call_manager.gas_tracker().milligas_used()
+    }
+
     fn gas_available(&self) -> i64 {
         self.call_manager.gas_tracker().gas_available()
     }
+    fn milligas_available(&self) -> i64 {
+        self.call_manager.gas_tracker().milligas_available()
+    }
 
     fn charge_gas(&mut self, name: &str, compute: i64) -> Result<()> {
         let charge = GasCharge::new(name, compute, 0);
-        self.call_manager.charge_gas(charge)
+        self.call_manager.gas_tracker_mut().charge_gas(charge)
+    }
+
+    fn charge_milligas(&mut self, name: &str, compute: i64) -> Result<()> {
+        self.call_manager
+            .gas_tracker_mut()
+            .charge_milligas(name, compute)?;
+        Ok(())
     }
 
     fn price_list(&self) -> &PriceList {
