@@ -6,10 +6,10 @@ use std::iter;
 
 use anyhow::Context as _;
 use cid::Cid;
+use fvm_ipld_encoding::{Cbor, DAG_CBOR};
 use fvm_shared::address::Address;
 use fvm_shared::clock::ChainEpoch;
 use fvm_shared::crypto::signature::Signature;
-use fvm_shared::encoding::{Cbor, DAG_CBOR};
 use fvm_shared::error::ErrorNumber::IllegalArgument;
 use fvm_shared::piece::PieceInfo;
 use fvm_shared::sector::{
