@@ -1,4 +1,5 @@
 use fvm_shared::error::ExitCode;
+use fvm_shared::sys::SyscallSafe;
 use fvm_shared::version::NetworkVersion;
 
 use super::error::Abort;
@@ -11,6 +12,8 @@ use crate::Kernel;
 #[derive(Copy, Clone)]
 pub enum Never {}
 
+unsafe impl SyscallSafe for Never {}
+
 // NOTE: this won't clobber the last syscall error because it directly returns a "trap".
 pub fn abort(
     context: Context<'_, impl Kernel>,
