@@ -1,16 +1,16 @@
 use anyhow::Context;
 use cid::Cid;
 use fvm_ipld_blockstore::Blockstore;
+use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
 use fvm_ipld_encoding::{Cbor, CborStore};
 use fvm_shared::address::Address;
-use serde::{Deserialize, Serialize};
 
 use crate::kernel::{ClassifyResult, Result};
 use crate::state_tree::{ActorState, StateTree};
 
 pub const SYSTEM_ACTOR_ADDR: Address = Address::new_id(0);
 
-#[derive(Default, Deserialize, Serialize)]
+#[derive(Default, Deserialize_tuple, Serialize_tuple)]
 pub struct State {
     // builtin actor registry: Vec<(String, Cid)>
     pub builtin_actors: Cid,
